summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/messagewidget.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
commit4ae0c208b66e0f7954e194384464fe2d0a2c56dd (patch)
treeb0a7cd1c184f0003c0292eb416ed27f674f9cc43 /umbrello/umbrello/messagewidget.h
parent1964ea0fb4ab57493ca2ebb709c8d3b5395fd653 (diff)
downloadtdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.tar.gz
tdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1157652 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/messagewidget.h')
-rw-r--r--umbrello/umbrello/messagewidget.h46
1 files changed, 23 insertions, 23 deletions
diff --git a/umbrello/umbrello/messagewidget.h b/umbrello/umbrello/messagewidget.h
index 66f2f639..29383405 100644
--- a/umbrello/umbrello/messagewidget.h
+++ b/umbrello/umbrello/messagewidget.h
@@ -78,14 +78,14 @@ public:
virtual ~MessageWidget();
/**
* Write property of QString m_SequenceNumber.
*/
- void setSequenceNumber( const QString &sequenceNumber );
+ void setSequenceNumber( const TQString &sequenceNumber );
/**
* Read property of QString m_SequenceNumber.
*/
- QString getSequenceNumber() const;
+ TQString getSequenceNumber() const;
/**
* Returns whether the message is synchronous or asynchronous
@@ -139,7 +139,7 @@ public:
* Implements operation from LinkWidget.
* Required by FloatingTextWidget.
*/
- void lwSetFont (QFont font);
+ void lwSetFont (TQFont font);
/**
* Overrides operation from LinkWidget.
@@ -164,13 +164,13 @@ public:
* Overrides operation from LinkWidget.
* Required by FloatingTextWidget.
*/
- QString getCustomOpText();
+ TQString getCustomOpText();
/**
* Overrides operation from LinkWidget.
* Required by FloatingTextWidget.
*/
- void setCustomOpText(const QString &opText);
+ void setCustomOpText(const TQString &opText);
/**
* Overrides operation from LinkWidget.
@@ -187,7 +187,7 @@ public:
* @param ft The text widget which to update.
* @param newText The new text to set.
*/
- void setText(FloatingTextWidget *ft, const QString &newText);
+ void setText(FloatingTextWidget *ft, const TQString &newText);
/**
* Overrides operation from LinkWidget.
@@ -196,7 +196,7 @@ public:
* @param seqNum The new sequence number string to set.
* @param op The new operation string to set.
*/
- void setSeqNumAndOp(const QString &seqNum, const QString &op);
+ void setSeqNumAndOp(const TQString &seqNum, const TQString &op);
/**
* Overrides operation from LinkWidget.
@@ -205,7 +205,7 @@ public:
* @param seqNum Return this MessageWidget's sequence number string.
* @param op Return this MessageWidget's operation string.
*/
- UMLClassifier * getSeqNumAndOp(QString& seqNum, QString& op);
+ UMLClassifier * getSeqNumAndOp(TQString& seqNum, TQString& op);
/**
* Calculate the geometry of the widget.
@@ -244,26 +244,26 @@ public:
/**
* Calls drawSynchronous() or drawAsynchronous()
*/
- void draw(QPainter& p, int offsetX, int offsetY);
+ void draw(TQPainter& p, int offsetX, int offsetY);
/**
* Draws the calling arrow with filled in arrowhead, the
* timeline box and the returning arrow with a dashed line and
* stick arrowhead.
*/
- void drawSynchronous(QPainter& p, int offsetX, int offsetY);
+ void drawSynchronous(TQPainter& p, int offsetX, int offsetY);
/**
* Draws a solid arrow line and a stick arrow head.
*/
- void drawAsynchronous(QPainter& p, int offsetX, int offsetY);
+ void drawAsynchronous(TQPainter& p, int offsetX, int offsetY);
/**
* Draws a solid arrow line and a stick arrow head to the
* edge of the target object widget instead of to the
* sequence line.
*/
- void drawCreation(QPainter& p, int offsetX, int offsetY);
+ void drawCreation(TQPainter& p, int offsetX, int offsetY);
/**
* Sets the text position relative to the sequence message.
@@ -319,17 +319,17 @@ public:
* between call line and return line does not count, i.e. if
* the point is located in that space the function returns 0.
*/
- int onWidget(const QPoint & p);
+ int onWidget(const TQPoint & p);
/**
* Saves to the "messagewidget" XMI element.
*/
- void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
+ void saveToXMI( TQDomDocument & qDoc, TQDomElement & qElement );
/**
* Loads from the "messagewidget" XMI element.
*/
- bool loadFromXMI( QDomElement & qElement );
+ bool loadFromXMI( TQDomElement & qElement );
protected:
/**
@@ -350,14 +350,14 @@ protected:
* like so: --->
* The direction can be either Qt::LeftArrow or Qt::RightArrow.
*/
- static void drawArrow( QPainter& p, int x, int y, int w,
+ static void drawArrow( TQPainter& p, int x, int y, int w,
Qt::ArrowType direction, bool useDottedLine = false );
/**
* Draw a solid (triangular) arrowhead pointing in the given direction.
* The direction can be either Qt::LeftArrow or Qt::RightArrow.
*/
- static void drawSolidArrowhead(QPainter& p, int x, int y, Qt::ArrowType direction);
+ static void drawSolidArrowhead(TQPainter& p, int x, int y, Qt::ArrowType direction);
/**
* Update the UMLWidget::m_bResizable flag according to the
@@ -366,16 +366,16 @@ protected:
void updateResizability();
// Data loaded/saved
- QString m_SequenceNumber;
- QString m_CustomOp;
+ TQString m_SequenceNumber;
+ TQString m_CustomOp;
/**
* Whether the message is synchronous or asynchronous
*/
Uml::Sequence_Message_Type m_sequenceMessageType;
private:
- void moveEvent(QMoveEvent */*m*/);
- void resizeEvent(QResizeEvent */*re*/);
+ void moveEvent(TQMoveEvent */*m*/);
+ void resizeEvent(TQResizeEvent */*re*/);
ObjectWidget * m_pOw[2];
FloatingTextWidget * m_pFText;
@@ -78,14 +78,14 @@ public:
virtual ~MessageWidget();
/**
- * Write property of QString m_SequenceNumber.
+ * Write property of TQString m_SequenceNumber.
*/
@@ -78,14 +78,14 @@ public:
/**
- * Read property of QString m_SequenceNumber.
+ * Read property of TQString m_SequenceNumber.
*/